Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

101 documents were found matching the selected criteria.
Page: [ 1] 2 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
Napoleon v. Green | 7-13-17 | The City failed to prove beyond a reasonable doubt an essential element of Napoleon Codified Ordinance 339.02(a)—namely, that the vehicle operated by the defendant was of a gross weight of 10,000 pounds or more. The City did not lay a proper foundation regarding what training and experience the law enforcement officer had with the weight of trucks to be able to testify that the weight of the defendant’s truck was of a gross weight of 10,000 pounds or more. | Preston | 7/21/2014 | 2014-Ohio-3192
Shelby Ct. Bd. of Commrs. v. Kimpel | 17-13-20 | The trial court did not err in finding the board of commissioners was not entitled to recover for salary paid during a suspension pursuant to R.C. 3.16 when the felony conviction was unrelated to the suspension and had not been reviewed by a special commission as required by statute. | Willamowski | 7/21/2014 | 2014-Ohio-3191
In re N.G. | 5-13-35 | The trial court erred in finding that admission to a community corrections facility was the same as an admission to a deparment of youth services faciility. Trial court erred in dismissing the motion to vacate the sentence as an untimely petiition for post-conviction relief. | Willamowski | 7/21/2014 | 2014-Ohio-3190
Wormsley v. Wormsley | 9-14-04 | The trial court did not abuse its discretion in awarding wife spousal support based on husband’s overtime hours and pay where husband consistently worked overtime throughout the course of the marriage. The trial court did not err in ordering spousal support to be paid for an indeterminate period of time where the marriage lasted thirty-eight years and the wife did not earn a significant income during the marriage. There is no evidence in the record supporting husband’s contention that the trial court erred in awarding attorney’s fees to wife. | Shaw | 7/14/2014 | 2014-Ohio-3086
State v. Norman | 13-13-50 | The trial court did not err in sentencing defendant-appellant because the sentence was supported by the record and, even assuming defendant-appellant did not waive the issue of sentence proportionality for appeal, the sentence was not disproportionate to sentences in similar cases. | Preston | 7/7/2014 | 2014-Ohio-3010
State v. Peddicord | 7-13-12 | The trial court did not err in imposing consecutive sentences where the findings required under R.C. 2929.14(C)(4) were supported by the record. | Willamowski | 6/30/2014 | 2014-Ohio-2849
P & J Design Servs., Inc. v. Linton | 2-13-30 | The trial court's interpretation of the contract and the amount of damages was not against the manifest weight of the evidence. | Willamowski | 6/30/2014 | 2014-Ohio-2848
State v. Duncan | 8-12-15 | Verdict forms were insufficient to support a conviction on anything but the least degree of the offense. | Willamowski | 6/23/2014 | 2014-Ohio-2720
State v. Shenfeld | 11-13-13 | The record supports the trial court's imposition of sentence and thus trial court did not err in imposing appellant's sentence of six years for robbery, a felony of the second degree. | Shaw | 6/23/2014 | 2014-Ohio-2719
Mueller v. All-Temp Refrig., Inc. | 15-13-08 | Plaintiffs-Appellants, Stan (“Stan”) and Shirley (“Shirley”) Mueller (collectively, “the Muellers”), appeal the judgment of the Court of Common Pleas of Van Wert County dismissing their complaint in favor of Defendant-Appellee, All-Temp Refrigeration Inc. (“All-Temp”). On appeal, the Muellers contend that the trial court erred by: (1) not finding that an express warranty for future performance was created pursuant to R.C. 1302.26; (2) finding that the Muellers’ contract with All-Temp was for a sale of goods; (3) not finding that the actions and representations of All-Temp created an express warranty; and (4) dismissing their claim for relief under the Consumer Sales Practices Act. For the reasons that follow, we affirm the trial court’s judgment. | Rogers | 6/23/2014 | 2014-Ohio-2718
State ex rel. Patrick Bros., A Gen. Partnership v. Putnam Cty. Bd. of Commrs. | 12-13-05 | The trial court erred by not finding violations of Ohio's Open Meetings Law when requested notice was not given, the commissioners had no policy for providing proper notice, and the commissioners failed to keep appropriate minutes of general meetings. The commissioners failed to follow statutory procedures in appropriating property for the widening of the road. | Willamowski | 6/23/2014 | 2014-Ohio-2717
State v. Hurley | 6-13-02 | State failed to show defendant knowingly sold counterfeit heroin, therefore his convictions are reversed on those counts for lack of sufficient evidence. Court also failed to make the appropriate findings pursuant to R.C. 2929.14(C)(4) to impose consecutive sentences. However, Hurley's remaining convictions affirmed, and the trial court did not err in failing to merge Hurley's Trafficking and Criminal Tools offenses. | Shaw | 6/23/2014 | 2014-Ohio-2716
Krill v. Krill | 4-13-15 | The trial court did not abuse its discretion by naming defendant-appellee the residential parent and legal custodian of the parties' children. Because plaintiff-appellant failed to object to the magistrate's decision finding her in contempt and failed to assign or argue plain error on appeal, the court on appeal was not required to address her contempt-related arguments. | Preston | 6/16/2014 | 2014-Ohio-2577
State v. Ayala | 14-13-22 | Appellant's aggravated menacing conviction was not based on insufficient evidence and was not against the manifest weight of the evidence. | Preston | 6/16/2014 | 2014-Ohio-2576
St. Marys v. Internal. Assn. of Firefighters Local 3633 | 2-13-29 | Trial court's decision to vacate arbitration award is affirmed as arbitrator's award departed from essence of parties' collective bargaining agreement. | Shaw | 6/16/2014 | 2014-Ohio-2575
State v. Seitz | 17-12-11 | Jury verdicts were not inconsistent as conviction for Kidnapping did not require the completion of a Felonious Assault; rather, Kidnapping punishes certain removal or restraint done with a certain purpose, and the eventual success of failure of the goal is irrelevant. | Shaw | 6/9/2014 | 2014-Ohio-2463
State v. Ropp | 14-13-21 | While the trial court must be cautious to sentence for the crimes for which the defendant was convicted, it may consider other evidence within reason in imposing a sentence. The trial court did not err in imposing consecutive sentences. | Willamowski | 6/9/2014 | 2014-Ohio-2462
In re F.I. | 13-13-19 | Appeal dismissed for lack of jurisdiction. | Shaw | 6/2/2014 | 2014-Ohio-2336
Hawk v. Stocklin | 1-13-56 | The trial court erred in granting the insurance company’s motion for summary judgment based upon an exclusion in the policy for bodily injury either arising out of an assault or battery or expected or intended from the standpoint of the insured when there is a question of fact as to whether the bodily injury was the result of an insured acting in self-defense. | Shaw | 6/2/2014 | 2014-Ohio-2335
State v. Perkins | 9-13-52 | The trial court abused its discretion by ordering that defendant-appellant pay restitution in the amount of $177,470 because the restitution order did not bear a reasonable relationship to the actual loss suffered by the victim. | Preston | 5/27/2014 | 2014-Ohio-2242
State ex rel. Karr Revocable Trust v. Zehringer | 10-13-18 | The trial court did not abuse its discretion in granting the writ of mandamus requested by relators-appellees because respondents-appellants had a clear legal duty under Ohio Constitution, Article I, Section 19 to deposit in appropriation proceedings money equal to the values of the permanent and perpetual flowage easements of which respondents-appellants have already taken possession and any damages to the residue of relators-appellees’ properties, and because relators-appellees have no plain and adequate remedy at law. | Preston | 5/27/2014 | 2014-Ohio-2241
State v. Crider | 1-13-20 | The trial court did not err in allowing the defendant to represent himself after it had conducted an extensive dialogue with the defendant and the explained the risks associated with doing so. The defendant was determined not to have the assistance of counsel. The trial court did not err in denying the motion to continue made by defendant in the middle of trial after the defendant fired his attorney as they were already a day and a half into the proceedings and a continuance would have meant bringing the jury back at later dates. Defendant was not denied effective assistance of counsel. The record contains no evidence that defendant's Fourth Amendment rights were violated. Defendant's Fifth Amendment rights were not violated by failure to advise him of his Miranda rights since he did not make any statements and thus no statements were used against him. The indictment in this case set forth separate and distinct charges and was not a "carbon-copy" indictment. The trial court erred by failng to make findings before imposing consecutive sentences. | Willamowski | 5/27/2014 | 2014-Ohio-2240
State v. Daley | 13-13-26 | Trial court did not err by allowing testimony concerning behavior of a State’s witness; the error in instructing the jury was not plain error; the defendant was not denied effective assistance of counsel; and the jury’s findings on the charges of child endangering and kidnapping were not against the manifest weight of the evidence. | Willamowski | 5/19/2014 | 2014-Ohio-2128
State v. Peace | 5-13-32 | The trial court was without the authority to impose the term of postrelease control because Appellant had already completed the stated prison terms for the offenses which were the only portion of his aggregate sentence to which the postrelease control sanction applied. | Shaw | 5/19/2014 | 2014-Ohio-2126
In re L.O. | 9-13-66 | Trial court's judgment entry is unclear as to whether it exercised discretion in ordering juvenile to comply with community notification requirements or felt compelled to do so. | Shaw | 5/19/2014 | 2014-Ohio-2125
Bonvillian v. Clark | 10-13-20 | The trial court did not abuse its discretion when it did not grant defendant-appellant a deviation from the guideline amount of child support calculated using the R.C. 3119.022 worksheet under R.C. 3119.24. | Preston | 5/12/2014 | 2014-Ohio-2003
Erter v. Erter | 8-13-16 | Trial court did not abuse its discretion in denying wife's contempt motion. | Shaw | 5/5/2014 | 2014-Ohio-1882
State v. Hoover | 13-13-47, 13-13-48, 13-13-49 | Defendant-Appellant, Seth Hoover, appeals the judgment of the Court of Common Pleas of Seneca County denying his motion to vacate a void and unenforceable negotiated plea bargain agreement and sentence and by failing to correct the language in his plea agreement regarding the imposition of five years of post-release control. Hoover also argues that he was denied effective assistance of counsel. For the following reasons, we affirm the trial court’s judgment. | Rogers | 5/5/2014 | 2014-Ohio-1881
State v. Panning | 15-13-07 | Defendant-Appellant, Bobby Panning, appeals the judgment of the Court of Common Pleas of Van Wert County, convicting him of sexual battery. On appeal, Panning argues that the trial court erred by (1) classifying him as a Tier III Sex Offender; and (2) imposing consecutive sentences. Panning also argues he was denied effective assistance of counsel. For the reasons that follow, we reverse the trial court’s judgment. | Rogers | 5/5/2014 | 2014-Ohio-1880
Am. Trim, L.L.C. v. L&T Technologies, Inc. | 2-13-25 | Defendants-Appellants, L&T Technologies, Inc. (“L&T”) and Thomas Belmont, appeal the judgment of the Court of Common Pleas of Auglaize County awarding Plaintiff-Appellee, American Trim, LLC (“American Trim”), a monetary award. On appeal, L&T and Belmont argue that the court committed the following errors: (1) finding that American Trim expressly rejected goods by notifying L&T as required by the Uniform Commercial Code (“UCC”); and (2) finding that Belmont had engaged in fraud. For the reasons that follow, we affirm in part and reverse in part the trial court’s judgment. | Rogers | 5/5/2014 | 2014-Ohio-1879
State v. Lasenby | 1-13-36 | Defendant-Appellant, Willie Lasenby, appeals the judgment of the Court of Common Pleas of Allen County, convicting him of one count of rape and sentencing him to a prison term of eight years. On appeal, Lasenby argues that the trial court erred by entering a guilty verdict that was against the manifest weight of the evidence. Lasenby also claims that he was denied the effective assistance of counsel. For the reasons that follow, we affirm the trial court’s judgment. | Rogers | 5/5/2014 | 2014-Ohio-1878
State v. Land | 9-13-39 | Plaintiff-Appellant, the State of Ohio, appeals the judgment of the Court of Common Pleas of Marion County, suppressing the State’s evidence. On appeal, the State argues that the trial court erred by: (1) holding a suppression hearing after the commencement of trial without the defendant filing a motion to suppress; (2) denying the State due process; and (3) improperly suppressing the State’s evidence. For the reasons that follow, we reverse the trial court’s judgment. | Rogers | 5/5/2014 | 2014-Ohio-1877
Hartings v. Xu | 10-13-11 | Plaintiffs-Appellants, Hillary Hartings; Rebecca Bruns, Administratrix of the Estate of Aubrey Bruns; Rebecca and John Bruns, as parents and natural guardians of Conner D. Bruns; Rebecca Bruns and John Bruns, as parents and natural guardians of Keaton Bruns; Rebecca Bruns, individually; and John Bruns, individually (collectively “Hartings”), and Defendants-Appellants, the National Mutual Insurance Company d/b/a Celina Insurance Group and Ohio Mutual Insurance Company (collectively “the Insurance Companies”), appeal the judgment of the Court of Common Pleas of Mercer County, granting summary judgment in favor of Defendants-Appellees, Jinghao Xu; Asiana Floors, Jung Ho Bae, and Kim Bae (collectively “the Baes”); and Rite Rug Company (“Rite Rug”). On appeal, Hartings and the Insurance Companies argue that the trial court committed the following errors: (1) granting summary judgment in favor of Rite Rug and the Baes by finding that Xu was an independent contractor; (2) granting summary judgment as the decision was based upon a mistake of law; and (3) granting summary judgment in favor of Rite Rug and the Baes on the issue of negligent hiring and retention of Xu. For the reasons that follow, we reverse in part and affirm in part the trial court’s judgment. | Rogers | 4/28/2014 | 2014-Ohio-1794
State v. Taylor | 1-13-46 | Defendant-Appellant, Maurice Taylor, appeals the judgment of the Court of Common Pleas of Allen County convicting him of domestic violence and sentencing him to 18 months in prison. On appeal, Taylor argues that the trial court erred by scheduling his trial outside of the statutorily required speedy trial date and by entering a guilty verdict that was against the manifest weight of the evidence. For the reasons that follow, we affirm the trial court’s judgment. | Rogers | 4/28/2014 | 2014-Ohio-1793
In re S.F. | 5-13-36 | The trial court did not abuse its discretion in determining that it was in the best interest of the child to terminate the parental rights and grant permanent custody to the Agency. The Agency did not fail to make a reasonable case plan designed to reunite the child with his mother. | Willamowski | 4/28/2014 | 2014-Ohio-1792
State v. Stairhime | 4-13-06 | Appellant's ten convictions for sexual offenses against various victims were not against the manifest weight of the evidence. Appellant was unable to establish his counsel was ineffective. In addition, Appellant did not establish that his sentence was clearly and convincingly contrary to law. | Shaw | 4/28/2014 | 2014-Ohio-1791
White-Rhoades v. Rhoades | 9-13-60 | The trial court did not err in allocating to the parties equal shares of the appreciation in the real property owned by wife due to the fact that improvements made to the property were paid for out of a marital account containing comingled separate and marital funds. | Shaw | 4/28/2014 | 2014-Ohio-1790
State v. Montgomery | 12-13-11 | The trial court did not err by accepting defendant-appellant's guilty plea. The trial court properly advised defendant-appellant of his rights pursuant to Crim.R. 11(C)(2). Defendant-appellant waived his argument concerning venue by pleading guilty and failing to raise the issue below. The trial court did not violate defendant-appellant's right of allocution under Crim.R. 32(A)(1). | Preston | 4/28/2014 | 2014-Ohio-1789
State v. Velez | 12-13-10 | Defendant-appellant's convictions for felonious assault and menacing were supported by sufficient evidence and not against the manifest weight of the evidence. The trial court did not commit plain error when it denied defendant-appellant's motion for separate trials. The trial court did not commit plain error by not questioning a juror concerning his hearing ability or by retaining the juror. The trial court did not commit plain error by allowing plaintiff-appellee to question defendant-appellant during his cross-examination concerning his military discharge. | Preston | 4/28/2014 | 2014-Ohio-1788
State v. Bagley | 1-13-31 | Defendant-appellant's conviction for felonious assault was not against the manifest weight of the evidence because defendant-appellant failed to prove self-defense. The trial court did not err in admitting a part of the interview between defendant-appellant and the investigating detective in which defendant-appellant refers to his prior incarceration. The trial court did not err in admitting a part of the interview between defendant-appellant and the investigating detective in which the detective questions defendant-appellant’s truthfulness. Defendant-appellant waived his constitutional arguments by not raising them in the trial court. | Preston | 4/28/2014 | 2014-Ohio-1787
State v. Rock | 13-13-38 | The trial court did not err in denying defendant-appellant's Crim.R. 29 motion for acquittal because a rational trier of fact could have found the essential elements of tampering with evidence proven beyond a reasonable doubt. | Preston | 4/28/2014 | 2014-Ohio-1786
State v. Graham | 5-13-31 | Defendant’s sentence was a final appealable order, the sentence was not void and the allegations regarding the trial court’s sentencing errors, brought to the attention of the trial court almost thirteen years after the sentencing and direct appeal, were barred by res judicata. | Willamowski | 4/28/2014 | 2014-Ohio-1785
Cunningham v. Cunningham | 11-13-08 | Court's decision not to factor-in depreciation for previous years' farming expenses when calculating gross income for child support purposes not an abuse of discretion. Similarly, trial court's award of partial attorney fees not an abuse of discretion. | Shaw | 4/21/2014 | 2014-Ohio-1684
State v. Hiser | 11-13-04 | Trial court did not err in denying the motion for a continuance when defendant was unable to estimate when he would be ready and had already had over a year to prepare the defense. Defendant was not denied effective assistance of counsel. | Willamowski | 4/21/2014 | 2014-Ohio-1683
Crites v. Anthem Life Ins. Co. | 4-13-13 | The trial court did not err by granting the decedent's children summary judgment and imposing a constructive trust over the proceeds of the decedent's employer-sponsored life insurance policy after distribution of the policy proceeds to the decedent's ex-wife. | Preston | 4/21/2014 | 2014-Ohio-1682
Liles v. Doyle | 1-13-48 | The trial court did not abuse its discretion by denying appellant-father's complaint for legal custody of his minor child. | Preston | 4/21/2014 | 2014-Ohio-1681
State v. Peacock | 13-13-42 | Trial court did not abuse its discretion in denying appellant's motion to withdraw his guilty plea. | Shaw | 4/14/2014 | 2014-Ohio-1571
State v. Loman | 2-13-17 | By setting as a condition of defendant-appellant’s bond that he contact his counsel once each week and then directing defendant-appellant’s counsel to provide the information, evidence, or testimony necessary to establish the violation of that bond condition against defendant-appellant’s interests, the trial court denied defendant-appellant the effective assistance of his counsel. | Shaw | 4/14/2014 | 2014-Ohio-1570
Weisenauer v. Am. Standard, Inc. | 13-13-25 | Summary Judgment improper under White v. Mayfield where claimant has not yet "quit work on account of disease." | Shaw | 4/14/2014 | 2014-Ohio-1569
State v. Stober | 12-13-09 | Sufficient evidence was presented to support Stober's convictions and convictions were not against the manifest weight of the evidence. A joint trial for victims of similar crimes was not error. Witnesses' testimony was properly allowed under Evid.R. 404(B). Jury instructions adequately reflected the law. Prosecutor did not commit misconduct, and counsel was not ineffective. Trial court did, however, fail to make all of the required findings for consecutive sentences. | Shaw | 4/14/2014 | 2014-Ohio-1568
State v. Land | 9-13-49 | Land's conviction for trafficking in heroin not against the manifest weight of the evidence. | Shaw | 4/14/2014 | 2014-Ohio-1566
In re M.H. | 13-13-45, 13-13-46 | The trial court's dispositional decision relative to mother-appellant's minor child, M.H., was not against the manifest weight of the evidence. Mother-appellant failed to object to the magistrate's decision with respect to W.H., and the trial court's disposition of W.H. did not amount to plain error. | Preston | 4/7/2014 | 2014-Ohio-1485
Kingseed v. Dininger | 13-13-39 | Plaintiff-Appellant, Dennis Kingseed, appeals the judgment of the Tiffin Municipal Court awarding him damages in a forcible entry and detainer action against Defendant-Appellee, Karen Dininger. On appeal, Kingseed argues that the trial court erred by improperly calculating his damages. Finding that the damages calculation is not supported by some competent, credible evidence, we reverse the trial court’s judgment. | Rogers | 4/7/2014 | 2014-Ohio-1484
State v. Coleman | 5-13-15 | The trial court did not err by denying defendant-appellant's motion to suppress evidence when the traffic stop was supported by probable cause of a turn-signal violation. Alleged racial profiling is not grounds for suppression of evidence under the Fourth Amendment. | Preston | 4/7/2014 | 2014-Ohio-1483
Grange Ins. Co. v. Sawmiller | 2-13-19 | PTSD and physical symptoms stemming therefrom do not fall under the definition of “bodily injury” in the Grange automobile insurance policy; and therefore, the trial court did not err in granting Grange summary, declaratory judgment. | Preston | 4/7/2014 | 2014-Ohio-1482
In re S.B. | 5-13-27; 5-13-28; 5-13-29 | The termination of the parental rights of the mother was not against the manifest weight of the evidence. The Agency made a good faith effort to reunify the children with their mother. | Willamowski | 4/7/2014 | 2014-Ohio-1481
Geesaman v. St. Rita's Med. Ctr. | 1-13-08 | Plaintiffs-Appellants, Jeffrey (“Jeffrey”) and Lori (“Lori”) Geesaman (collectively, “Appellants”), appeal the judgment of the Court of Common Pleas of Allen County granting summary judgment in favor of Defendant-Appellee, John Cox, D.O. On appeal, Appellants argue that the trial court erroneously interpreted our previous opinion in this matter as limiting the retrial to the issue of loss of chance. See Geesaman v. St. Rita’s Med. Ctr., 183 Ohio App.3d 555, 2009-Ohio-3931 (3d Dist.) (hereinafter, “Geesaman I”). For the reasons that follow, we reverse the trial court’s judgment. | Rogers | 4/7/2014 | 2014-Ohio-1480
State v. Parr | 15-13-09 | Defendant's plea was not entered involuntarily regardless of sentence attorney may have promised when defendant was questioned by the trial court and stated that he understood that the trial court was the sole determiner of the sentence and that he understood what the possible sentences were. | Willamowski | 4/7/2014 | 2014-Ohio-1479
State v. Opp | 13-13-33 | The trial court did not abuse its discretion when it admitted an expert witness's testimony in spite of the State's failure to comply with Crim.R. 16(K). | Willamowski | 3/24/2014 | 2014-Ohio-1138
State v. Nisley | 5-13-25 | Defendant-Appellant, Nathan Nisley, appeals the judgment of the Court of Common Pleas of Hancock County convicting him of attempted aggravated possession of drugs and sentencing him to 120 days in jail. On appeal, Nisley argues that the trial court committed the following errors: denying his presentence motions which, collectively, constituted a withdrawal of his guilty plea; and denying his motion for a second psychological evaluation prior to the sentencing hearing. Nisley also argues that he was denied effective assistance of counsel. For the reasons that follow, we affirm the trial court’s judgment. | Shaw | 3/24/2014 | 2014-Ohio-1137
In re I.G. | 9-13-43, 9-13-44, 9-13-45 | Mother-appellant fully participated in final hearing and thus any defect in notification was waived. Grant of permanent custody was supported by clear and convincing evidence. | Shaw | 3/24/2014 | 2014-Ohio-1136
State v. Bardhi | 11-13-05 | Insufficient evidence was presented to convict defendant of speeding in violation of former R.C. 4511.21(D)(3) where State did not offer any evidence of vehicle's weight exceeding 8,000 pounds, one of the two required elements. | Shaw | 3/24/2014 | 2014-Ohio-1135
State v. Arnold | 13-13-27 | Defendant's conviction for Domestic Violence was not against the manifest weight of the evidence. He is unable to establish that the trial court was biased against him, or that his fifth or sixth amendment rights were violated. | Shaw | 3/24/2014 | 2014-Ohio-1134
State v. Roth | 7-13-10 | The trial court did not err in overruling the appellant’s motion to suppress and excluding evidence on the ground of hearsay. | Shaw | 3/17/2014 | 2014-Ohio-984
State v. Wilkins | 17-13-13 | The trial court did not commit plain error when it ordered that defendant-appellant pay the victim restitution in the amount of $21,281. Defendant-appellant was not denied effective assistance of counsel. | Preston | 3/17/2014 | 2014-Ohio-983
State v. Bright | 13-13-30 | Defendant-appellant's breaking and entering convictions were supported by sufficient evidence and not against the manifest weight of the evidence. The trial court did not abuse its discretion by denying defendant-appellant's motion to sever. The trial court did not abuse its discretion by allowing testimony concerning the significant decrease in break-ins following the search of defendant-appellant's residence. | Preston | 3/17/2014 | 2014-Ohio-982
State v. Nisley | 5-13-23 | Defendant-Appellant, Nathan Nisley, appeals the judgment of the Court of Common Pleas of Hancock County convicting him of attempted aggravated possession of drugs and sentencing him to 120 days in jail. On appeal, Nisley argues that the trial court committed the following errors: denying his presentence motions which, collectively, constituted a withdrawal of his guilty plea; and denying his motion for a second psychological evaluation prior to the sentencing hearing. Nisley also argues that he was denied effective assistance of counsel. For the reasons that follow, we affirm the trial court’s judgment. | Rogers | 3/17/2014 | 2014-Ohio-981
State v. Wilkerson | 8-13-06, 8-13-07 | The trial court’s failure to make all of the required specific findings for imposition of consecutive sentences resulted in the defendant’s sentence being contrary to law. | Willamowski | 3/17/2014 | 2014-Ohio-980
In re ZA.C. | 1-13-43, 1-13-44 | Trial court did not err in finding that the children could not be placed with either parent within a reasonable time or in determining that granting permanent custody to the agency was in the best interest of the child. Mother was not denied effective assistance of counsel. Trial court did not err in limiting questioning as to who was a confidential informant in a related criminal case when that information was not relevant to this case. | Willamowski | 3/17/2014 | 2014-Ohio-979
State v. Dirmeyer | 13-13-24 | The trial court did not err in instructing the jury pursuant to State v. Lilly, 87 Ohio St.3d 97 (1997) that "one can commit a trespass and burglary against property of which one is the legal owner if another has control or custody of that property." The trial court did not err by denying defendant-appellant's Crim.R. 29(A) motion since sufficient evidence existed to show he trespassed into the residence since defendant-appellant's former girlfriend had sole possessory interest in the residence after defendant-appellant vacated, returned his key, removed most of his belongings, asked to have his name removed off the lease, and did not reside in the residence for six months prior to the incident. | Preston | 3/3/2014 | 2014-Ohio-759
State v. Schmidt | 13-13-07 | Under Crim.R. 12(C)(2), Defendant waived objections to the alleged defects in the indictment’s forfeiture specification when he failed to raise the challenge in the trial court. | Willamowski | 3/3/2014 | 2014-Ohio-758
Hopkins v. Porter | 10-13-17 | Because the chip spreader was not a "motor vehicle" for purposes of R.C. 2744.02(B)(1) or an "obstruction" for purposes of R.C. 2744.02(B)(3), the trial court did not err by granting the Mercer County Board of County Commissioners summary judgment. Because there is no question of fact concerning whether Porter, the county employee responsible for the accident, acted recklessly, the trial court erred by denying Porter summary judgment under R.C. 2744.03(A)(6). | Preston | 3/3/2014 | 2014-Ohio-757
Cotton v. Sheldon | 9-13-48 | Plaintiff-Appellant, Prince Charles Cotton, appeals the judgment of the Court of Common Pleas of Marion County denying his “motion to rescind unauthorized actions by the clerk’s [sic] of courts”. On appeal, Cotton argues that the trial court erred because the judge was biased, cited his own personal opinions, failed to cite case law, and misapplied the law. For the reasons that follow, we affirm the trial court’s judgment. | Rogers | 3/3/2014 | 2014-Ohio-756
In re H.M. | 8-13-11, 8-13-12, 8-13-13 | Appellant, Marla Lewellan, appeals the judgment of the Court of Common Pleas of Logan County granting permanent custody of her three minor children, H.M., L.L., and J.L., to Logan County Children Services (“LCCS”). On appeal, Lewellan argues that the trial court erred by: entering a judgment that was against the manifest weight of the evidence; improperly focusing on Lewellan’s mental health; and failing to make independent findings of fact and conclusions of law. Lewellan also argues that LCCS did not use reasonable efforts to reunify the family, that the guardian ad litem (“GAL”) for her children did not adequately perform his duties; and that her GAL did not adequately perform his duties. For the reasons that follow, we reverse the judgment of the trial court and remand this matter for further proceedings consistent with this opinion. | Rogers | 3/3/2014 | 2014-Ohio-755
State v. Michael | 7-13-05 | The trial court did not err in revoking the defendant’s suspended sentence upon his failure to comply with conditions of suspension. | Willamowski | 3/3/2014 | 2014-Ohio-754
State v. Henson | 5-13-24 | Defendant-appellant's cocaine-possession conviction was not against the manifest weight of the evidence. | Preston | 3/3/2014 | 2014-Ohio-753
State v. Perkins | 5-13-01 | Evidence was sufficient to prove "venue" was appropriate in Hancock County. Appellant's right to remain silent was not violated, counsel was not ineffective, prosecutor did not engage in misconduct. References to appellant's bond status did not rise to the level of reversible error. | Shaw | 3/3/2014 | 2014-Ohio-752
State v. Lyle | 1-13-16, 1-13-17 | Defendant-Appellant, Brandon Lyle, appeals the judgments of the Court of Common Pleas of Allen County finding that he violated his community control in two different cases and sentencing him to a one year prison term in each, to be served consecutively. On appeal, Lyle argues that the trial court erred by: (1) failing to adequately notify him of the possibility of a prison sentence if he violated the terms of his community control; and (2) imposing consecutive sentences. For the reasons that follow, we affirm the judgment in Appeal No. 1-13-17 and reverse the judgment in Appeal No. 1-13-16. | Rogers | 3/3/2014 | 2014-Ohio-751
State v. Reed | 16-13-11 | Defendant-Appellant, David Reed, appeals the judgment of the Court of Common Pleas of Wyandot County convicting him of two counts of rape and one count of gross sexual imposition and sentencing him to 25 years to life in prison. On appeal, Reed argues that the trial court erred by: (1) denying his motion for acquittal at the end of the State’s evidence; and (2) entering a guilty verdict that was against the manifest weight of the evidence. Reed also contends that he was denied effective assistance of counsel. For the reasons that follow, we affirm the trial court’s judgment. | Rogers | 2/24/2014 | 2014-Ohio-644
State v. Gonzales | 13-13-31, 13-13-32 | Search warrant was supported by probable cause, was not overbroad, and the no-knock provision was not improper. However, sentence to permanent weapons disability was improper under amended statute. | Shaw | 2/18/2014 | 2014-Ohio-557
State v. Raymond | 1-13-23 | The trial court did not err by ordering defendant-appellant to serve his Allen County term of imprisonment consecutive to his Auglaize County term of imprisonment. Trial counsel was not ineffective for failing to present mitigation evidence at the sentencing hearing where the evidence was already before the sentencing court and the defendant-appellant made a statement in mitigation. | Preston | 2/18/2014 | 2014-Ohio-556
State v. White | 1-13-27 | Trial court did not err in denying defendant's motion to suppress evidence collected at an OVI roadblock. | Willamowski | 2/18/2014 | 2014-Ohio-555
BAC Home Loans Servicing, L.P. v. Haas | 9-13-40 | The trial court did not err in overruling the appellants-homeowners’ motion for Civ.R. 60(B) relief from judgment and motion to enforce settlement agreement with appellee-lender. | Shaw | 2/10/2014 | 2014-Ohio-438
State v. Love | 9-13-09 | Failure to merge Vandalism and Arson against the same victim for actions stemming from same course of conduct was error. Restitution order improper where no conviction against the victims and no agreement in the written plea agreement to do so. | Shaw | 2/10/2014 | 2014-Ohio-437
State v. Fisher | 6-13-03 | Defendant-appellant's convictions were not against the manifest weight of the evidence. | Preston | 2/10/2014 | 2014-Ohio-436
State v. Shoulders | 5-13-12, 5-13-20 | The trial court did not abuse its discretion in denying defendant-appellant's postsentence motion to withdraw his guilty plea. Defendant-appellant was not denied effective assistance of counsel. | Preston | 2/10/2014 | 2014-Ohio-435
Kelly v. Kelly | 5-13-10 | The trial court did not err in denying the motion for shared parenting. The trial court did not err in designated the mother as residential parent. The decision of the trial court was not against the manifest weight of the evidence. | Willamowski | 2/3/2014 | 2014-Ohio-354
State v. Johnston | 8-13-10 | Defendant-appellant's conviction for breaking and entering was supported by sufficient evidence. Defendant-appellant was not denied effective assistance of counsel. | Preston | 2/3/2014 | 2014-Ohio-353
Buchanan v. Improved Properties, L.L.C. | 1-13-38 | Trial court did not err in granting summary judgment to seller of real estate when buyer had opportunity to have property inspected, had the home inspected, and bought the property "as is." | Willamowski | 1/27/2014 | 2014-Ohio-263
State v. Hale | 9-13-17 | The trial court made factual findings under R.C. 2951.03(B)(5) even though it did not expressly state so. The trial court’s failure to make an R.C. 2951.03(B)(5) factual finding regarding the age of the victim was harmless error. The trial court made the appropriate R.C. 2929.14(C) findings prior to imposing consecutive sentences. The trial court did not err in sentencing defendant-appellant to 14 years imprisonment. | Preston | 1/27/2014 | 2014-Ohio-262
State v. Miller | 13-13-14 | Defendant-appellant's endangering-children conviction was not against the manifest weight of the evidence. Defendant-appellant was not denied effective assistance of counsel. | Preston | 1/27/2014 | 2014-Ohio-261
State v. Rickman | 13-13-15 | The trial court did not abuse its discretion in denying Defendant's motion to withdraw guilty plea. | Willamowski | 1/27/2014 | 2014-Ohio-260
State v. Liles | 1-13-04 | Defendant-appellant’s felonious assault and weapons under disability convictions were not against the manifest weight of the evidence. Defendant-appellant was not deprived effective assistance of counsel. | Preston | 1/27/2014 | 2014-Ohio-259
State v. Workman | 10-13-13 | The trial court erred in finding Appellant was guilty of violating the local zoning code when the complaint, the evidence at trial, and the judgment entry of conviction and sentence all failed as a matter of law to sufficiently apprise Appellant of or identify for the record the proscribed criminal conduct for which Appellant was purportedly convicted. | Shaw | 1/27/2014 | 2014-Ohio-258
Buchenroth v. Adkins | 8-13-17 | Trial court erred in failing to award contracted rate of interest. | Shaw | 1/27/2014 | 2014-Ohio-257
State v. Coe | 12-13-03 | The prosecutor committed misconduct during the State's case-in-chief, opening statements, and closing arguments by claiming that defendant was guilty because he refused to answer the questions of the police, thus commenting on the defendant's exercise of his right to remain silent. | Willamowski | 1/27/2014 | 2014-Ohio-256
State v. Billenstein | 10-13-10 | Defendant-Appellant, Ryan Billenstein, appeals the judgment of the Mercer County Court of Common Pleas finding him guilty of two counts of aggravated vehicular manslaughter, one count of vehicular assault, and driving under the influence and sentencing him to 13 years in prison. On appeal, Billenstein contends that the trial court erred by: (1) failing to suppress in-custody statements Billenstein made; (2) failing to orally advise Billenstein that counts one, two, and five of the indictment carried a mandatory term of incarceration; (3) failing to orally advise Billenstein that he would be ineligible for community control and judicial release; (4) failing to advise Billenstein of the elements of post release control; (5) failing to advise Billenstein of the mandatory suspension of his operator’s license; and (6) imposing consecutive sentences. Billenstein also argues that he was denied effective assistance of counsel. For the reasons that follow, we affirm in part and reverse in part the trial court’s judgment. | Rogers | 1/27/2014 | 2014-Ohio-255
State v. Hayes | 13-13-21 | Defendant's conviction was not against the manifest weight of the evidence. Defendant was not denied effective assistance of counsel. | Willamowski | 1/27/2014 | 2014-Ohio-254
Brown v. Wyandt | 8-13-08 | The trial court’s finding that appellant failed to establish he had standing as a nonparent to pursue a shared custody petition against appellee was supported by competent, credible, and reliable evidence. | Shaw | 1/21/2014 | 2014-Ohio-164
Snapp v. Castlebrook Builders, Inc. | 17-12-22 | There was no prejudicial error in holding individual defendant personally liable for co-defendant corporation’s actions; the trial court did not abuse its discretion in awarding treble damages and attorney’s fees pursuant to R.C. 1345.09; and the jury verdicts were not inconsistent or against manifest weight of the evidence. | Willamowski | 1/21/2014 | 2014-Ohio-163

Page: [ 1] 2 next